@@ -3,19 +3,23 @@ package Beekeeper;
 use strict;
 use warnings;
 
-our $VERSION = '0.02_03';
+our $VERSION = '0.03';
 
 1;
 
 __END__
 
+=pod
+
+=encoding utf8
+
 =head1 NAME
  
 Beekeeper - Framework for building applications with a microservices architecture
  
 =head1 VERSION
  
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -91,16 +95,18 @@ Beekeeper is a framework for building applications with a microservices architec
 
 =end HTML
 
-A pool of worker processes handle requests and communicate with each other through a common message bus.
+A pool of worker processes handle requests and communicate with each other through a common 
+message bus.
 
-Clients send requests through a different set of message buses, which are isolated for security reasons.
+Clients send requests through a different set of message buses, which are isolated for security 
+reasons.
 
 Requests and responses are shoveled between buses by a few router processes.
 
 
 B<Benefits of this architecture:>
 
-- Scales horizontally very well. It is easy to add or remove workers or brokers.
+- Scales horizontally very well. It is easy to add or remove workers, routers or brokers.
 
 - High availability. The system remains responsive even when several components fail.
 
@@ -109,9 +115,9 @@ B<Benefits of this architecture:>
 
 B<Key characteristics:>
 
-- Broker is a messaging server like Apache ActiveMQ or RabbitMQ.
+- Broker is a MQTT messaging server, like Mosquitto or HiveMQ.
 
-- Broker protocol is STOMP (see the specification at L<https://stomp.github.io/stomp-specification-1.2.html>).
+- Broker protocol is MQTT 5 (see the specification at L<https://docs.oasis-open.org/mqtt/mqtt/v5.0/mqtt-v5.0.html>).
 
 - RPC protocol is JSON-RPC 2.0 (see the specification at L<https://www.jsonrpc.org/specification>).
 
@@ -121,22 +127,24 @@ B<Key characteristics:>
 
 - No routing logic is defined in the broker.
 
-- Efficient multicast and unicast notifications.
+- Blends synchronous and asynchronous workers or clients.
+
+- Efficient multicast and unicast push notifications.
 
 - Inherent load balancing.
 
 
 B<What does this framework provides:>
 
-- C<Beekeeper::Worker>, a base class for writing service workers with almost no additional code.
+- C<Beekeeper::Worker>, to create service workers.
 
-- C<Beekeeper::Client>, a class for writing service clients.
+- C<Beekeeper::Client>, to create service clients.
 
 - C<bkpr> command which spawns and controls worker processes.
 
-- Command line tools for monitoring and controlling remotely worker pools.
+- Command line tools for monitoring and controlling worker pools.
 
-- A simple internal broker handy for development or running tests. 
+- An internal broker suitable for development or running tests. 
 
 - Automatic message routing between frontend and backend buses.
 
@@ -147,11 +155,11 @@ B<What does this framework provides:>
 
 =head1 Getting Started
 
-=head3 Writing workers
+=head3 Creating workers
 
 Workers provide a service accepting certain RPC calls from clients. The base class C<Beekeeper::Worker> 
-provides all the glue needed to accept requests and communicate trough the message bus with clients or 
-another workers.
+provides all the glue needed to accept requests and communicate trough the message bus with 
+clients or another workers.
 
 A worker class just declares on startup which methods it will accept, then implements them:
 
@@ -174,11 +182,11 @@ A worker class just declares on startup which methods it will accept, then imple
   }
 
 
-=head3 Writing clients
+=head3 Creating clients
 
 Clients of the service need an interface to use it without knowledge of the underlying RPC 
-mechanisms. The class C<Beekeeper::Client> provides simple methods to connect to the broker 
-and make RPC calls.
+mechanisms. The class C<Beekeeper::Client> provides methods to connect to the broker and make 
+RPC calls.
 
 This is the interface of the above service:
 
@@ -208,13 +216,13 @@ Then other workers or clients can just:
 
 =head3 Configuring
 
-Beekeeper applications use two config files to define how clients, workers and brokers 
-connect to each other. These files are searched for in ENV C<BEEKEEPER_CONFIG_DIR>, 
-C<~/.config/beekeeper> and then C</etc/beekeeper>. File format is relaxed JSON, which 
-allows comments and trailings commas.
+Beekeeper applications use two config files to define how clients, workers and brokers connect 
+to each other. These files are searched for in ENV C<BEEKEEPER_CONFIG_DIR>, C<~/.config/beekeeper> 
+and then C</etc/beekeeper>. File format is relaxed JSON, which allows comments and trailings 
+commas.
 
-The file C<pool.config.json> defines all worker pools running on a host, specifying 
-which logical bus should be used and which services it will run. For example:
+The file C<pool.config.json> defines all worker pools running on a host, specifying which logical 
+bus should be used and which services it will run. For example:
 
   [{
       "pool-id" : "myapp",
@@ -224,16 +232,15 @@ which logical bus should be used and which services it will run. For example:
       },
   }]
 
-The file C<bus.config.json> defines all logical buses used by the application, specifying 
-the connection parameters to the brokers that will service them. For example:
+The file C<bus.config.json> defines all logical buses used by the application, specifying the 
+connection parameters to the brokers that will service them. For example:
 
-  {
-     "bus-id"  : "backend",
-     "host"    : "localhost",
-     "user"    : "backend",
-     "pass"    : "def456",
-     "vhost"   : "/back",
-  ]
+  [{
+      "bus-id"   : "backend",
+      "host"     : "localhost",
+      "username" : "backend",
+      "password" : "def456",
+  }]
 
 Neither the worker code nor the client code have hardcoded references to the logical message 
 bus or the broker connection parameters, they communicate to each other using the definitions 
@@ -259,10 +266,70 @@ The framework includes these command line tools to manage worker pools:
 - C<bkpr-restart> gracefully restarts local or remote worker pools.
 
 
-=head3 Examples
+=head1 Performance
 
-This distribution includes some examples that can be run out of the box using an internal
-`ToyBroker` (so no install of a proper broker is needed):
+Beekeeper is pretty lightweight, so the performance depends mostly on *the broker* performance. 
+These are 
+ballpark performance measurements of a local setup running Mosquitto:
+
+- A C<do_job> synchronous call to a remote method adds 1.5 ms of latency and involves 4 network 
+round trips. This implies a maximum of 650 synchronous calls per second.
+
+- A C<do_async_job> asynchronous call to a remote method takes 0.1 ms. This implies a maximum 
+of 10000 asynchronous calls per second (just the call, then it must wait for responses).
+
+- Scheduling a remote task with C<do_background_job> takes 0.1 ms. This implies a maximum of 
+10000 calls per second.
+
+- Sending a notification with C<send_notification> takes 0.1 ms. A worker can emit 10000 notifications 
+per second, even over 15000 if these are smaller than 1 KB.
+
+- A worker processing remote calls adds 0.3 ms of latency and involves 2 network round trips. 
+So a single worker can handle a maximum of 3300 requests per second.
+
+- A worker adds an overhead of 0,04% CPU load per request.
+
+- A worker uses 10 MB of resident memory.
+
+- Frontend router adds 5 ms of latency and involves 2 additional network round trips.
+
+B<Hypothetical example:>
+
+Suppose it is needed to handle 1000 requests per second to a task that takes 25 ms to complete, 
+uses 20 MB of memory and has 2% CPU load. Servers are in the same datacenter and the network 
+roundtrip is 0.1 ms.
+
+Adding framework and network latency, a single worker can handle:
+
+  1000 ms / (25 ms + 0.3 ms + 0.1 ms * 2) = 39 req/s
+
+In order to handle 1000 requests per second:
+
+  1000 req/s / 39 req/s = 26 workers
+
+The memory needed is:
+
+  26 workers * (20 MB + 10 MB) = 780 MB
+
+The CPU needed is:
+
+  26 * 2% + 1000 * 0,04% = 92% = 1 core
+
+End user latency is:
+
+  25 ms + 0.3 ms + 5 ms + 0.1 ms * 6 = 31 ms + user latency
+
+Backend broker receives 2000 msg/s and sends 2000 msg/s, giving a 4000 msg/s total traffic.
+Frontend broker receives 1000 msg/s and sends 1000 msg/s, giving a 2000 msg/s total traffic.
+
+These numbers will improve a bit when running on beefier CPUs, and worsen a lot if broker performance 
+degrades under heavy load.
+
+
+=head1 Examples
+
+This distribution includes some examples that can be run out of the box using an internal C<ToyBroker> 
+(so no install of a proper broker is needed):
 
 C<examples/basic> is a barebones example of the usage of Beekeper.
 
@@ -273,34 +340,25 @@ C<examples/webstomp> use a service from a browser using WebSockets.
 C<examples/chat> implements a real world setup with isolated buses and redundancy.
 
 
-=head3 TODO
-
-Since this project was started (and even then) STOMP has been completely surpassed 
-as a fast and simple messaging protocol by MQTT. And since 2019, when MQTT
-version 5.0 was released, many brokers started to implement the routing features
-needed by Beekeeper to run.
-
-So the underlying broker protocol should be changed to MQTT, in order to take advantage
-of better supported modern brokers.
-
-
 =head1 SEE ALSO
- 
+
+L<Notes about supported MQTT brokers|https://github.com/jmico/beekeeper/blob/master/doc/Brokers.md> configuration.
+
+L<Diagram of message routing|https://raw.githubusercontent.com/jmico/beekeeper/master/doc/images/routing.svg> between clients, workers and buses.
+
 L<Beekeeper::WorkerPool>, L<Beekeeper::Client>, L<Beekeeper::Worker>.
 
 =head1 SOURCE REPOSITORY
  
 The source code repository for Beekeeper can be found at L<https://github.com/jmico/beekeeper>
 
-=encoding utf8
-
 =head1 AUTHOR
 
 José Micó, C<jose.mico@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015 José Micó.
+Copyright 2015-2021 José Micó.
 
 This is free software; you can redistribute it and/or modify it under the same 
 terms as the Perl 5 programming language itself.
