@@ -3,7 +3,33 @@ package Beekeeper::JSONRPC::Notification;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.03';
+
+use Beekeeper::JSONRPC::AuthHeaders ':all';
+
+
+sub new {
+    my $class = shift;
+
+    bless {
+        jsonrpc => '2.0',
+        method  => undef,
+        params  => undef,
+        @_
+    }, $class;
+}
+
+sub method { $_[0]->{method} }
+sub params { $_[0]->{params} }
+sub id     { undef           }
+
+1;
+
+__END__
+
+=pod
+
+=encoding utf8
 
 =head1 NAME
  
@@ -11,7 +37,7 @@ Beekeeper::JSONRPC::Notification - Representation of a JSON-RPC notification.
  
 =head1 VERSION
  
-Version 0.01
+Version 0.03
 
 =head1 DESCRIPTION
 
@@ -35,36 +61,13 @@ It is always undef.
 
 =back
 
-=cut
-
-use Beekeeper::JSONRPC::AuthHeaders ':all';
-
-sub new {
-    my $class = shift;
-
-    bless {
-        jsonrpc => '2.0',
-        method  => undef,
-        params  => undef,
-        @_
-    }, $class;
-}
-
-sub method { $_[0]->{method} }
-sub params { $_[0]->{params} }
-sub id     { undef           }
-
-1;
-
-=encoding utf8
-
 =head1 AUTHOR
 
 José Micó, C<jose.mico@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015 José Micó.
+Copyright 2015-2021 José Micó.
 
 This is free software; you can redistribute it and/or modify it under the same 
 terms as the Perl 5 programming language itself.
