@@ -3,59 +3,11 @@ package Beekeeper::JSONRPC::Request;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
-
-=head1 NAME
- 
-Beekeeper::JSONRPC::Request - Representation of a JSON-RPC request.
- 
-=head1 VERSION
- 
-Version 0.01
-
-=head1 SYNOPSIS
-
-  my $client = Beekeeper::Client->instance;
-  
-  my $req = $client->do_async_job(
-      method => 'myapp.svc.foo',
-      params => { foo => 'bar' },
-  );
-  
-  $client->wait_all_jobs;
-
-  die unless ($req->success);
-
-  print $req->result;
-
-=head1 DESCRIPTION
-
-Objects of this class represents a JSON-RPC request (see L<http://www.jsonrpc.org/specification>).
-
-Method C<Beekeeper::Client-\>do_async_job> returns objects of this class.
-
-=head1 ACCESSORS
-
-=over 4
-
-=item method
-
-A string with the name of the method to be invoked.
-
-=item params
-
-An arbitrary data structure to be passed as parameters to the defined method.
-
-=item id
-
-A value of any type, which is used to match responses with requests.
-
-=back
-
-=cut
+our $VERSION = '0.03';
 
 use Beekeeper::JSONRPC::AuthHeaders ':all';
 
+
 sub new {
     my $class = shift;
     bless {
@@ -87,13 +39,66 @@ sub success {
 
 1;
 
+__END__
+
+=pod
+
+=encoding utf8
+
+=head1 NAME
+ 
+Beekeeper::JSONRPC::Request - Representation of a JSON-RPC request.
+ 
+=head1 VERSION
+ 
+Version 0.03
+
+=head1 SYNOPSIS
+
+  my $client = Beekeeper::Client->instance;
+  
+  my $req = $client->do_async_job(
+      method => 'myapp.svc.foo',
+      params => { foo => 'bar' },
+  );
+  
+  $client->wait_all_jobs;
+  
+  die unless ($req->success);
+  
+  print $req->result;
+
+=head1 DESCRIPTION
+
+Objects of this class represents a JSON-RPC request (see L<http://www.jsonrpc.org/specification>).
+
+Method C<Beekeeper::Client-\>do_async_job> returns objects of this class.
+
+=head1 ACCESSORS
+
+=over 4
+
+=item method
+
+A string with the name of the method to be invoked.
+
+=item params
+
+An arbitrary data structure to be passed as parameters to the defined method.
+
+=item id
+
+A value of any type, which is used to match responses with requests.
+
+=back
+
 =head1 AUTHOR
 
 José Micó, C<jose.mico@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015 José Micó.
+Copyright 2015-2021 José Micó.
 
 This is free software; you can redistribute it and/or modify it under the same 
 terms as the Perl 5 programming language itself.
