@@ -3,7 +3,67 @@ package Beekeeper::Service::Router;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.03';
+
+use Exporter 'import';
+
+our @EXPORT_OK = qw(
+    bind_connection
+    unbind_connection
+    unbind_address
+);
+
+our %EXPORT_TAGS = ('all' => \@EXPORT_OK );
+
+
+sub bind_connection {
+    my ($self, $address) = @_;
+
+    my $req = $self->{_CLIENT}->{curr_request} or die "No connection to bind";
+
+    $self->do_job(
+        method => '_bkpr.router.bind',
+        __auth => 'BKPR_ROUTER',
+        params => {
+            address     => $address, 
+            reply_queue => $req->{_headers}->{'fwd_reply'},
+            session_id  => $self->{_CLIENT}->{session_id},
+            auth_tokens => $self->{_CLIENT}->{auth_tokens},
+        },
+    );
+}
+
+sub unbind_connection {
+    my $self = shift;
+
+    $self->do_job(
+        method => '_bkpr.router.unbind',
+        __auth => 'BKPR_ROUTER',
+        params => {
+            session_id => $self->{_CLIENT}->{session_id},
+        },
+    );
+}
+
+sub unbind_address {
+    my ($self, $address) = @_;
+
+    $self->do_job(
+        method => '_bkpr.router.unbind',
+        __auth => 'BKPR_ROUTER',
+        params => {
+            address => $address, 
+        },
+    );
+}
+
+1;
+
+__END__
+
+=pod
+
+=encoding utf8
 
 =head1 NAME
 
@@ -11,7 +71,7 @@ Beekeeper::Service::Router - Route messages between buses
 
 =head1 VERSION
 
-Version 0.01
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -51,69 +111,13 @@ Cancel current client connection bind to an address.
 
 Cancel every connection bind to a given address.
 
-=cut
-
-use Exporter 'import';
-
-our @EXPORT_OK = qw(
-    bind_connection
-    unbind_connection
-    unbind_address
-);
-
-our %EXPORT_TAGS = ('all' => \@EXPORT_OK );
-
-
-sub bind_connection {
-    my ($self, $address) = @_;
-
-    my $req = $self->{_CLIENT}->{curr_request} or die "No connection to bind";
-
-    $self->do_job(
-        method => '_bkpr.router.bind',
-        __auth => 'BKPR_ROUTER',
-        params => {
-            address     => $address, 
-            reply_queue => $req->{_headers}->{'x-forward-reply'},
-            session_id  => $self->{_CLIENT}->{session_id},
-            auth_tokens => $self->{_CLIENT}->{auth_tokens},
-        },
-    );
-}
-
-sub unbind_connection {
-    my $self = shift;
-
-    $self->do_job(
-        method => '_bkpr.router.unbind',
-        __auth => 'BKPR_ROUTER',
-        params => {
-            session_id => $self->{_CLIENT}->{session_id},
-        },
-    );
-}
-
-sub unbind_address {
-    my ($self, $address) = @_;
-
-    $self->do_job(
-        method => '_bkpr.router.unbind',
-        __auth => 'BKPR_ROUTER',
-        params => {
-            address => $address, 
-        },
-    );
-}
-
-1;
-
 =head1 AUTHOR
 
 José Micó, C<jose.mico@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015 José Micó.
+Copyright 2015-2021 José Micó.
 
 This is free software; you can redistribute it and/or modify it under the same 
 terms as the Perl 5 programming language itself.
