@@ -3,36 +3,9 @@ package Beekeeper::Service::Sinkhole::Worker;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
-
-=head1 NAME
- 
-Beekeeper::Service::Sinkhole::Worker - Handle unserviced job queues
-
-=head1 VERSION
- 
-Version 0.01
-
-=head1 DESCRIPTION
-
-In the case of all workers of a given service being down, all requests sent to
-the service will timeout as no one is serving them. This may cause a serious
-disruption in the application, as any other service depending of the broken
-one will halt too for the duration of the timeout.
-
-In order to mitigate this situation all Sinkhole workers will be notified by
-the Supervisor when unserviced queues are detected, making these to respond 
-immediately to all requests with an error response. Then callers will quickly 
-receive an error response instead of timing out.
-
-As soon as a worker of the downed service becomes online again the Sinkhole
-workers will stop rejecting requests.
-
-A Sinkhole worker is created automatically in every worker pool, and it can 
-handle around 500 req/s. Extra workers can simply be declared into config file.
-
-=cut
+our $VERSION = '0.03';
 
+use AnyEvent::Impl::Perl;
 use Beekeeper::Worker ':log';
 use base 'Beekeeper::Worker';
 
@@ -65,11 +38,12 @@ sub on_startup {
 
     # Watch the Supervisor data traffic in order to stop rejecting
     # requests as soon as a worker handling these becomes online
+
     $self->{_BUS}->subscribe(
-        destination    => "/topic/msg.$local_bus._sync.workers.set",
-        on_receive_msg => sub {
-            my ($body_ref, $msg_headers) = @_;
-            $self->on_worker_status( decode_json($$body_ref)->[1] );
+        topic      => "msg/$local_bus/_sync/workers/set",
+        on_publish => sub {
+            my ($payload_ref, $properties) = @_;
+            $self->on_worker_status( decode_json($$payload_ref)->[1] );
         }
     );
 }
@@ -81,7 +55,6 @@ sub log_handler {
     $self->SUPER::log_handler( foreground => 1 );
 }
 
-
 sub on_unserviced_queues {
     my ($self, $params) = @_;
 
@@ -96,7 +69,7 @@ sub on_unserviced_queues {
         $self->{Draining}->{$queue} = 1;
 
         my $local_bus = $self->{_BUS}->{cluster};
-        log_error "Draining unserviced /queue/req.$local_bus.$queue";
+        log_error "Draining unserviced req/$local_bus/$queue";
 
         $self->accept_jobs( "$queue.*" => 'reject_job' );
     }
@@ -119,7 +92,7 @@ sub on_worker_status {
         delete $self->{Draining}->{$queue};
 
         my $local_bus = $self->{_BUS}->{cluster};
-        log_warn "Stopped draining /queue/req.$local_bus.$queue";
+        log_warn "Stopped draining req/$local_bus/$queue";
 
         $self->stop_accepting_jobs( "$queue.*" );
     }
@@ -143,15 +116,45 @@ sub reject_job {
 
 1;
 
+__END__
+
+=pod
+
 =encoding utf8
 
+=head1 NAME
+ 
+Beekeeper::Service::Sinkhole::Worker - Handle unserviced job queues
+
+=head1 VERSION
+ 
+Version 0.03
+
+=head1 DESCRIPTION
+
+In the case of all workers of a given service being down, all requests sent to
+the service will timeout as no one is serving them. This may cause a serious
+disruption in the application, as any other service depending of the broken
+one will halt too for the duration of the timeout.
+
+In order to mitigate this situation all Sinkhole workers will be notified by
+the Supervisor when unserviced queues are detected, making these to respond 
+immediately to all requests with an error response. Then callers will quickly 
+receive an error response instead of timing out.
+
+As soon as a worker of the downed service becomes online again the Sinkhole
+workers will stop rejecting requests.
+
+A Sinkhole worker is created automatically in every worker pool, and it can 
+handle around 500 req/s. Extra workers can simply be declared into config file.
+
 =head1 AUTHOR
 
 José Micó, C<jose.mico@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015 José Micó.
+Copyright 2015-2021 José Micó.
 
 This is free software; you can redistribute it and/or modify it under the same 
 terms as the Perl 5 programming language itself.
