@@ -3,27 +3,7 @@ package Beekeeper::Service::Supervisor;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
-
-=head1 NAME
-
-Beekeeper::Service::Supervisor - Worker pool supervisor.
-
-=head1 VERSION
-
-Version 0.01
-
-=head1 SYNOPSIS
-
-=head1 DESCRIPTION
-
-Supervisor service keeps a table of the status and performance metrics of every 
-worker connected to a logical bus in every broker.
-
-This status table can be queried to shovel worker status to an external monitoring
-application. The command line tool L<bkpr-top> display this status table.
-
-=cut
+our $VERSION = '0.03';
 
 use Beekeeper::Client;
 
@@ -67,9 +47,10 @@ sub get_workers_status {
     my $client = Beekeeper::Client->instance;
 
     my $resp = $client->do_job(
-        method => '_bkpr.supervisor.get_workers_status',
-        __auth => 'BKPR_ADMIN',
-        params => {
+        method  => '_bkpr.supervisor.get_workers_status',
+        __auth  => 'BKPR_ADMIN',
+        timeout => $args{'timeout'},
+        params  => {
             host  => $args{'host'},
             pool  => $args{'pool'},
             class => $args{'class'},
@@ -85,9 +66,10 @@ sub get_services_status {
     my $client = Beekeeper::Client->instance;
 
     my $resp = $client->do_job(
-        method => '_bkpr.supervisor.get_services_status',
-        __auth => 'BKPR_ADMIN',
-        params => {
+        method  => '_bkpr.supervisor.get_services_status',
+        __auth  => 'BKPR_ADMIN',
+        timeout => $args{'timeout'},
+        params  => {
             host  => $args{'host'},
             pool  => $args{'pool'},
             class => $args{'class'},
@@ -99,8 +81,30 @@ sub get_services_status {
 
 1;
 
+__END__
+
+=pod
+
 =encoding utf8
 
+=head1 NAME
+
+Beekeeper::Service::Supervisor - Worker pool supervisor.
+
+=head1 VERSION
+
+Version 0.03
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+Supervisor service keeps a table of the status and performance metrics of every 
+worker connected to a logical bus in every broker.
+
+This status table can be queried to shovel worker status to an external monitoring
+application. The command line tool L<bkpr-top> display this status table.
+
 =head1 SEE ALSO
  
 L<bkpr-top>, L<bkpr-restart>.
@@ -111,7 +115,7 @@ José Micó, C<jose.mico@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015 José Micó.
+Copyright 2015-2021 José Micó.
 
 This is free software; you can redistribute it and/or modify it under the same 
 terms as the Perl 5 programming language itself.
