@@ -30,6 +30,7 @@ sub on_startup {
         'test.signal' => 'signal',
         'test.fail'   => 'fail',
         'test.sleep'  => '_sleep',
+        'test.triang' => 'triangular',
         'test.fib1'   => 'fibonacci_1',
         'test.fib2'   => 'fibonacci_2',
         'test.echo'   => 'echo',
@@ -53,7 +54,9 @@ sub signal {
     my ($signal) = $params->{signal} =~ m/(\w+)/;  # untaint
     my ($pid)    = $params->{pid}    =~ m/(\d+)/;
 
-    sleep(rand() / 10); # helps to avoid signal races
+    my $sleep = exists $params->{after} ? $params->{after} : rand() * 2;
+
+    sleep $sleep;
 
     kill( $signal, $pid );
 }
@@ -68,12 +71,32 @@ sub fail {
     die Beekeeper::JSONRPC::Error->server_error( message => $params->{error}) if $params->{error};
 }
 
+sub echo {
+    my ($self, $params) = @_;
+
+    return $params;
+}
+
 sub _sleep {
     my ($self, $params) = @_;
 
     sleep $params;
 }
 
+sub triangular {
+    my ($self, $n) = @_;
+
+    return $n if ($n <= 1);
+
+    my $resp = $self->do_job(
+        method  => 'test.triang',
+        params  => $n - 1,
+        timeout => 3,
+    );
+
+    return $resp->result + $n;
+}
+
 sub fibonacci_1 {
     my ($self, $n) = @_;
 
@@ -116,10 +139,4 @@ sub fibonacci_2 {
     return $req1->result + $req2->result; 
 }
 
-sub echo {
-    my ($self, $params) = @_;
-
-    return $params;
-}
-
 1;
